$TITLE ('COS DCE Boot-mode Patchable Constants, version 01.02')
$PAGELENGTH(42)
;*****************************************************************************
; File -- patchcst.a51
; Purpose -- COS DCE 8051 boot code, patchable constants.  In this file are
;            defined and allocated various parameters which control operation
;            of the boot-mode software.  These parameters are copied from CODE
;            space, where they are allocated, to XDATA upon startup so that
;            they may be changed through simple data uploads.
;
;            ------------------------   --------------------------------------
; Authors -- Original code by ...       Adapted for Boot-mode by ...
;            ------------------------   --------------------------------------
;            Mr. Daniel B. Blackman     William I. Clement, Ph.D., President
;            P.O. Box 20627             Clement Engineering, Inc.
;            Oakland, CA  94620         1261 Dogwood Road
;            (510) 910-9047             Arnold, MD  21012-2220
;                                       (410) 518-6591
;            ------------------------   --------------------------------------
;
; Change History --
; 24Aug00   Code version v17088 accepted by WIC from DBB
; 15Sep00   WIC, Boot code version 01.00 delivered.
;*****************************************************************************

$SET (PATCHCST=1)
$INCLUDE(common.inc)

   CSEG  at  PATCHCST_SEG   ; This is where we place the patchable constants
                            ; in CODE space.  They will be copied from here
                            ; to a DIFFERENT address in XDATA by subroutine
                            ; 'COPY_PATCHABLE'.  The table 'patch_table'
                            ; (below) gives the starting address, destination
                            ; address, and number of bytes to copy to
                            ; facilitate this task.

patchable_CSEG:             ; beginning label (in CODE segment) of area to be
                            ; copied from CODE to XDATA upon initialization

;*****************************************************************************
;                          Flight Software version
;*****************************************************************************
FILL_TO_BOUNDARY   16, 0FFh
fsw_version   equ   0102h   ; version 01.02
cLFDSWVER:
   DB   LOW(fsw_version), HIGH(fsw_version)   ; Version number
;-----------------------------------------------------------------------------

;*****************************************************************************
; 'HSTERR_TABLE' provides conversion from diagnostic to HST error.
; Entries are pointers to HST error parameter.  Null pointers are for
; diagnostics which are NOT HST errors.
; NOTE:  'cHSTERR_TABLE' is the CODE segment label for this table.
;    When this table is copied to XDATA, it is placed elsewhere and label
;    'HSTERR_TABLE' reflects that XDATA location.  It is the XDATA location
;    ('HSTERR_TABLE') which is referenced in the software.
;*****************************************************************************
null_ptr   equ   0

FILL_TO_BOUNDARY   16, 0FFh
cHSTERR_TABLE:
   DW   null_ptr,     PARAM2,     PARAM3,     PARAM2     ; 00..03
   DW    SERIALN,    SERIALN,    SERIALN,   null_ptr     ; 04..07
   DW   null_ptr,   null_ptr,   null_ptr,   null_ptr     ; 08..0B
   DW   null_ptr,   null_ptr,   null_ptr,   null_ptr     ; 0C..0F

   DW   null_ptr,       RS17,   null_ptr,   null_ptr     ; 10..13
   DW   null_ptr,   null_ptr,   null_ptr,   null_ptr     ; 14..17
   DW    mLFMLWR,    mLFMUPR,    mLFMROM,   mLFCTIME     ; 18..1B
   DW   mLFCTIME,   null_ptr,   null_ptr,   mLFCTIME     ; 1C..1F

   DW   null_ptr,   null_ptr,   null_ptr,   null_ptr     ; 20..23
   DW   null_ptr,   null_ptr,   null_ptr,   null_ptr     ; 24..27
   DW   null_ptr,   null_ptr,   null_ptr,   null_ptr     ; 28..2B
   DW   null_ptr,   null_ptr,   null_ptr,       RS17     ; 2C..2F
;-----------------------------------------------------------------------------

;*****************************************************************************
; 'CRC_REGIONS' is an array of 12-byte structures used to implement
; background CRC checking over multiple regions of memory.  The contents of
; each element of the array are as follows:
;    (1)  Starting address in memory (16 bits, big-endian)
;    (2)  Number of bytes to check (16 bits, big-endian)
;    (3)  Memory space (0=XDATA, 1=CODE) (8-bits)
;    (4)  Next region number (8-bits)
;    (5)  CRC for this region (16-bits)
;    (6)  Previous CRC for this region, if non-zero (16-bits)
;    (7)  Diagnostic to send if CRCs miscompare, if MSB=5Ah (16-bits)
; The first entry is region '0', CRC determined by LFDCRC command ('LFMCRC')
; The second entry is region '1', CRC of the PROM. ('LFMROM')
; The third entry is region '2', CRC of the Lower Code Area. ('LFMLWR')
; The fourth entry is region '3', CRC of the Upper Code Area. ('LFMUPR')
; Regions 4-15, allocated here, are for expansion.
; NOTE:  The labels at the beginning and end of this code segment, 
;    'cCRC_REGIONS' and 'end_cCRC_REGIONS' define the maximum number
;    of regions allocated and, hence, allowed ('num_regions').
;    The software will check to ensure that no unauthorized region is
;    requested since this would lead to software 'scribbling' in memory.
; NOTE:  To halt background CRC calculations, merely make a region point to
;    a 'next region' beyond the allowable range (i.e. >= 'num_regions')
; NOTE:  The command 'DCE_LFDCRC' will populate Region 0 with data specific
;    to its assigned task and zero out the 'previous CRC' to prevent
;    diagnostic and/or HST error.  It will NOT change the 'next region'
;    specifier.  That is up to the operator to command such a change.
;    By default, the 'next region' is region 1.
; NOTE:  Upon commencing CRC calculations for any region, the CRC is shown
;    as zero.  The actual CRC value will be written once calculations are
;    complete.  Additionally, if an LFDCRC command is received, the current
;    region will be abandoned and Region 0 will be setup for this command and
;    CRC calculations will begin on Region 0 immediately.
; NOTE:  'cCRC_REGIONS' is the CODE segment label for this table.
;    When this table is copied to XDATA, it is placed elsewhere and label
;    'CRC_REGIONS' reflects that XDATA location.  It is the XDATA location
;    ('CRC_REGIONS') which is referenced in the software.
;*****************************************************************************
FILL_TO_BOUNDARY   16, 0FFh
cCRC_REGIONS:

; Region 0 (used by LFDCRC for its CRC region) ...
   DW   00000h, 00000h   ; starting address, number of bytes
   DB   0, 1             ; 0=XDATA space, next region is '1'
cLFMCRC:                 ; CRC mnemonic LFMCRC
   DW   0, 0             ; calculated CRC, previous CRC
   DW   0                ; diagnostic message to send if CRC error
cCRC_REGIONS_00:         ; label used for computing 'sz_regions'

; Region 1 (used for CRC of PROM) ...
   DW   00000h, 01800h   ; starting address, number of bytes
   DB   1, 2             ; 1=CODE space, next region is '2'
cLFMROM:                 ; CRC mnemonic LFMROM
   DW   0, 0             ; calculated CRC, previous CRC
   DW   DIAG001A         ; Diagnostic:  Bad ROM CRC
   
; Region 2 (used for CRC of Lower Code Area) ...
   DW   09800h, 02800h   ; starting address, number of bytes
   DB   1, 3             ; 1=CODE space, next region is '3'
cLFMLWR:                 ; CRC mnemonic LFMLWR
   DW   0, 0             ; calculated CRC, previous CRC
   DW   DIAG0018         ; Diagnostic:  Bad LCA CRC
   
; Region 3 (used for CRC of Upper Code Area) ...
   DW   0D800h, 02800h   ; starting address, number of bytes
   DB   1, 1             ; 1=CODE space, next region is '1'
cLFMUPR:                 ; Region 3 CRC is a named quantity
   DW   0, 0             ; calculated CRC, previous CRC
   DW   DIAG0019         ; Diagnostic:  Bad UCA CRC
   
; Region 4 ...
   DW   00000h, 00000h   ; starting address, number of bytes
   DB   0, 1             ; 0=XDATA space, next region is '1'
   DW   0, 0             ; calculated CRC, previous CRC
   DW   0                ; diagnostic message
   
; Region 5 ...
   DW   00000h, 00000h   ; starting address, number of bytes
   DB   0, 1             ; 0=XDATA space, next region is '1'
   DW   0, 0             ; calculated CRC, previous CRC
   DW   0                ; diagnostic message
   
; Region 6 ...
   DW   00000h, 00000h   ; starting address, number of bytes
   DB   0, 1             ; 0=XDATA space, next region is '1'
   DW   0, 0             ; calculated CRC, previous CRC
   DW   0                ; diagnostic message
   
; Region 7 ...
   DW   00000h, 00000h   ; starting address, number of bytes
   DB   0, 1             ; 0=XDATA space, next region is '1'
   DW   0, 0             ; calculated CRC, previous CRC
   DW   0                ; diagnostic message
   
; Region 8 ...
   DW   00000h, 00000h   ; starting address, number of bytes
   DB   0, 1             ; 0=XDATA space, next region is '1'
   DW   0, 0             ; calculated CRC, previous CRC
   DW   0                ; diagnostic message
   
; Region 9 ...
   DW   00000h, 00000h   ; starting address, number of bytes
   DB   0, 1             ; 0=XDATA space, next region is '1'
   DW   0, 0             ; calculated CRC, previous CRC
   DW   0                ; diagnostic message
   
; Region 10 ...
   DW   00000h, 00000h   ; starting address, number of bytes
   DB   0, 1             ; 0=XDATA space, next region is '1'
   DW   0, 0             ; calculated CRC, previous CRC
   DW   0                ; diagnostic message
   
; Region 11 ...
   DW   00000h, 00000h   ; starting address, number of bytes
   DB   0, 1             ; 0=XDATA space, next region is '1'
   DW   0, 0             ; calculated CRC, previous CRC
   DW   0                ; diagnostic message
   
; Region 12 ...
   DW   00000h, 00000h   ; starting address, number of bytes
   DB   0, 1             ; 0=XDATA space, next region is '1'
   DW   0, 0             ; calculated CRC, previous CRC
   DW   0                ; diagnostic message
   
; Region 13 ...
   DW   00000h, 00000h   ; starting address, number of bytes
   DB   0, 1             ; 0=XDATA space, next region is '1'
   DW   0, 0             ; calculated CRC, previous CRC
   DW   0                ; diagnostic message
   
; Region 14 ...
   DW   00000h, 00000h   ; starting address, number of bytes
   DB   0, 1             ; 0=XDATA space, next region is '1'
   DW   0, 0             ; calculated CRC, previous CRC
   DW   0                ; diagnostic message
   
; Region 15 ...
   DW   00000h, 00000h   ; starting address, number of bytes
   DB   0, 1             ; 0=XDATA space, next region is '1'
   DW   0, 0             ; calculated CRC, previous CRC
   DW   0                ; diagnostic message

end_cCRC_REGIONS:

; The software uses 'num_regions' to limit the allowed values for the
; 'next region' parameter. 'sz_regions' is the number of bytes used by
; each entry in the above table ...
sz_regions    equ   (cCRC_REGIONS_00 - cCRC_REGIONS)
num_regions   equ   (end_cCRC_REGIONS - cCRC_REGIONS)/sz_regions
;-----------------------------------------------------------------------------

;*****************************************************************************
; The housekeeping script is composed of 4-byte entries.  The first byte is
; the script opcode and the last byte is the repetition count -- how many
; successive entities of the same type (same opcode) to collect and put
; into housekeeping (also at successive addresses).  The opcodes (first byte)
; are:
;        00h -- End of script
;        01h -- Read bytes from CODE space
;        02h -- Read bytes from XDATA space (or memory-mapped I/O)
;        03h -- Read bytes from DATA space
; UNUSED 04h -- Read bytes from digital I/O w/ MUX setting
; UNUSED 05h -- Read BIT from digital I/O w/ MUX setting
;        06h -- Read bytes from Analog I/O
;        07h -- Move housekeeping pointer to specified address
;        08h -- Skip 'N' bytes of housekeeping packet
;        09h -- Clear 'N' bytes of housekeeping packet
;        0Ah -- NOP (leaves an empty line in the script for later use)
;        46h -- Read TDC 'A'
;        82h -- Read TDC 'B'
;
; Depending on script opcode, bytes 2 & 3 take on various meanings.  They are:
;     Opcode -- Bytes 2&3
;        01h -- 16-bit address (MSB first)
;        02h -- 16-bit address (MSB first)
;        03h -- 16-bit address (MSB first, ignored)
; UNUSED 04h -- 16-bit MUX address (MSB first)
; UNUSED 05h -- 8-bit MUX address, 8-bit bit-select mask
;        06h -- 8-bit MUX address, 8-bit MUX delay ctr.
;        07h -- 16-bit address to which to move HKP pointer
;        08h -- N/A
;        09h -- N/A
;        0Ah -- N/A
;        46h -- 8-bit TDC MUX address, 8-bit MUX delay ctr.
;        82h -- 8-bit TDC MUX address, 8-bit MUX delay ctr.
;
; Byte 4 is always the repetition count.
;
; NOTE:  'chkp_script' is the CODE segment label for this table.
;    When this table is copied to XDATA, it is placed elsewhere and label
;    'hkp_script' reflects that XDATA location.  It is the XDATA location
;    ('hkp_script') which is referenced in the software.
;*****************************************************************************

a2d_delay   equ   3   ; MUX settling time (multiples of 0.384 msec @ 8-MHz)

; The housekeeping script for Boot mode is below.  It does not contain all
; operate mode housekeeping items -- only those required for boot.
; NOTE:  In Boot Mode, the housekeeping buffer is 3440h - 383Fh.  When the
;    buffer is transferred to the CS computer, its upper address is masked
;    with 1Fh so as to produce addresses in the range 1440h - 183Fh (same
;    address range as for Operate Mode).
FILL_TO_BOUNDARY   16, 0FFh
chkp_script:
   DB   op_jump,   HIGH(3640h),   LOW(3640h),    0  ; jump to address 3640h
   ;
   DB   op_xdata,  HIGH(mLFDERR), LOW(mLFDERR), 24  ; LFDERR (8 bytes)
                                                    ; LFDERRP (16 bytes)
   DB   op_jump,   HIGH(3664h),   LOW(3664h),    0  ; jump
   ;
   DB   op_xdata,  HIGH(RS17),    LOW(RS17),    28  ; LFDCBUF
   DB   op_xdata,  HIGH(mLFCTIME), LOW(mLFCTIME), 4 ; LFCTIME
   DB   op_jump,   HIGH(36C0h),   LOW(36C0h),    0  ; jump
   ;
   DB   op_a2d,    08h,           a2d_delay,     4  ; LFTDVAA, MUX=08h (1)
                                                    ; LFTACT,  MUX=09h (1)
                                                    ; LFTHVFM, MUX=0Ah (1)
                                                    ; LFTHVPS, MUX=0Bh (1)
   DB   op_a2d,    0Dh,           a2d_delay,     1  ; LFTIP,   MUX=0Dh
   DB   op_a2d,    11h,           a2d_delay,     1  ; LFTDVAB, MUX=11h
   DB   op_a2d,    0Eh,           a2d_delay,     2  ; LFTAMPA, MUX=0Eh (1)
                                                    ; LFTAMPB, MUX=0Fh (1)
   DB   op_a2d,    0Ch,           a2d_delay,     1  ; LFTTDCA, MUX=0Ch
   DB   op_a2d,    10h,           a2d_delay,     1  ; LFTTDCB, MUX=10h
   DB   op_a2d,    12h,           a2d_delay,     2  ; LFTLVPC, MUX=12h (1)
                                                    ; LFTDCE,  MUX=13h (1)
   DB   op_jump,   HIGH(36CDh),   LOW(36CDh),    0  ; jump
   ;
   DB   op_a2d,    15h,           a2d_delay,     1  ; LFVP5DC, MUX=15h
   DB   op_jump,   HIGH(36D8h),   LOW(36D8h),    0  ; jump
   ;
   DB   op_TDC_A,  50h,           a2d_delay,     1  ; LFVP15TA, TDC_A MUX=50h
   DB   op_TDC_B,  50h,           a2d_delay,     1  ; LFVP15TB, TDC_B MUX=50h
   DB   op_TDC_A,  52h,           a2d_delay,     1  ; LFVP5TA,  TDC_A MUX=52h
   DB   op_TDC_B,  52h,           a2d_delay,     1  ; LFVP5TB,  TDC_B MUX=52h
   DB   op_TDC_A,  51h,           a2d_delay,     1  ; LFVM15TA, TDC_A MUX=51h
   DB   op_TDC_B,  51h,           a2d_delay,     1  ; LFVM15TB, TDC_B MUX=51h
   DB   op_TDC_A,  53h,           a2d_delay,     1  ; LFVM5TA,  TDC_A MUX=53h
   DB   op_TDC_B,  53h,           a2d_delay,     1  ; LFVM5TB,  TDC_A MUX=53h
   DB   op_a2d,    16h,           a2d_delay,     2  ; LFVP15D,  MUX=16h (1)
                                                    ; LFVM15D,  MUX=17h (1)
   DB   op_jump,   HIGH(36E4h),   LOW(36E4h),    0  ; jump
   ;
   DB   op_xdata,  HIGH(mLFSBITS2), LOW(mLFSBITS2), 2  ; 'Status bits 2'
   DB   op_jump,   HIGH(36FCh),   LOW(36FCh),    0  ; jump
   ;
   DB   op_xdata,  HIGH(mLFMROM), LOW(mLFMROM),   2 ; LFMROM
   DB   op_xdata,  HIGH(mLFDSWVER), LOW(mLFDSWVER), 2  ; LFDSWVER
   DB   op_xdata,  HIGH(mLFCPKTL), LOW(mLFCPKTL), 5 ; LFCPKT (4)
                                                    ; LFDLSTC (1)
   DB   op_jump,   HIGH(3706h),   LOW(3706h),     0 ; jump
   ;
   DB   op_TDC_A,  54h,           a2d_delay,     1  ; LFGREFA,  TDC_A MUX=54h
   DB   op_TDC_B,  54h,           a2d_delay,     1  ; LFGREFB,  TDC_B MUX=54h
   DB   op_xdata,  HIGH(tLFDDIAGS+0), LOW(tLFDDIAGS+0), 1  ; LFDDIAG0
   DB   op_xdata,  HIGH(tLFDDIAGS+2), LOW(tLFDDIAGS+2), 1  ; LFDDIAG1
   DB   op_jump,   HIGH(370Ch),   LOW(370Ch),    0  ; jump
   ;
   DB   op_xdata,  HIGH(mLFDCMDX), LOW(mLFDCMDX), 2 ; LFDCMDX
   DB   op_jump,   HIGH(3710h),   LOW(3710h),     0 ; jump
   ;
   DB   op_a2d,    43h,           a2d_delay,     1  ; LFVPMON,  MUX=43h
   DB   op_xdata,  HIGH(tLFDDIAGS+4), LOW(tLFDDIAGS+4), 1  ; LFDDIAG2
   DB   op_jump,   HIGH(3718h), LOW(3718h),      0  ; jump
   ;
   DB   op_xdata,  HIGH(mLFDCMDR), LOW(mLFDCMDR), 2 ; LFDCMDR
   DB   op_xdata,  HIGH(mLFMCRC), LOW(mLFMCRC),   2 ; LFDCRC
   DB   op_jump,   HIGH(3730h),   LOW(3730h),     0 ; jump
   ;
   DB   op_xdata,  HIGH(mLFDPERF), LOW(mLFDPERF), 2 ; LFDPERF
   DB   op_jump,   HIGH(3736h),   LOW(3736h),     0 ; jump
   ;
   DB   op_xdata,  HIGH(mLFDMEXTR), LOW(mLFDMEXTR), 26  ; LFDMEXTR (1)
                                                        ; LFDMDATA (1)
                                                        ; LFDMONS (8)
                                                        ; LFDMADD (16)
   DB   op_jump,   HIGH(3776h),   LOW(3776h),    0  ; jump
   ;
   DB   op_xdata,  HIGH(tLFDDIAGS+6), LOW(tLFDDIAGS+6), 1 ; LFDDIAG3
   DB   op_xdata,  HIGH(tLFDDIAGS+8), LOW(tLFDDIAGS+8), 1 ; LFDDIAG4
   DB   op_jump,   HIGH(377Ch),   LOW(377Ch),    0  ; jump
   ;
   DB   op_xdata,  HIGH(mLFMLWR), LOW(mLFMLWR),  2  ; LFDLWR
   DB   op_xdata,  HIGH(mLFMUPR), LOW(mLFMUPR),  2  ; LFDUPR
   DB   op_xdata,  HIGH(mLFDDIAGS), LOW(mLFDDIAGS), 64  ; LFDDIAGS
   DB   op_a2d,    80h,           a2d_delay,     2  ; MUX=80h, DCE-A +5V
                                                    ; MUX=81h, DCE-B +5V
   ;
   ; The rest is blank -- leave it so.
   ;
   DB   op_end,    0,0,0 ; end of script

   ; Save room for future growth of the script ...
   DW   0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
   DW   0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
   DW   0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
   DW   0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
   DW   0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
   DW   0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
   DW   0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
   DW   0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
;-----------------------------------------------------------------------------

end_patchable_CSEG:         ; ending label (in CODE segment) of area to be
                            ; copied from CODE to XDATA upon initialization

; The above patchable constants will be copied to XDATA beginning at address
; 'PC04' (see common.inc).

;*****************************************************************************
; 'patch_table' is a list of all blocks of patchable constants which are to be
; copied from CODE to XDATA.  Each entry is composed of 3 words:
; (1)  CODE segment block starting address
; (2)  XDATA destination address
; (3)  Number of bytes to copy
; If the number of bytes is zero, that indicates the end of 'patch_table'.
;*****************************************************************************
FILL_TO_BOUNDARY   16, 0FFh
patch_table:
   DW   patchable_CSEG, PC04, end_patchable_CSEG-patchable_CSEG
   DW   0, 0, 0   ; end of patch_table
;-----------------------------------------------------------------------------

;*****************************************************************************
; Those patchable constants which are referred to BY NAME in the software
; must have their XDATA address specified as an equate.  Since they reside
; in the CODE segment beginning at address 'patchable_CSEG' and in XDATA
; beginning at address 'PC04', we merely add to the CODE segment address the
; difference between these two offsets to find the XDATA address.
;*****************************************************************************
mLFDSWVER      equ   cLFDSWVER     + (PC04-patchable_CSEG)
mLFMCRC        equ   cLFMCRC       + (PC04-patchable_CSEG)
mLFMROM        equ   cLFMROM       + (PC04-patchable_CSEG)
mLFMLWR        equ   cLFMLWR       + (PC04-patchable_CSEG)
mLFMUPR        equ   cLFMUPR       + (PC04-patchable_CSEG)
HSTERR_TABLE   equ   cHSTERR_TABLE + (PC04-patchable_CSEG)
CRC_REGIONS    equ   cCRC_REGIONS  + (PC04-patchable_CSEG)
hkp_script     equ   chkp_script   + (PC04-patchable_CSEG)
;-----------------------------------------------------------------------------

;*****************************************************************************
; In order to prevent accidentally overlapping XDATA memory usage, we will
; block out an area of XDATA of the same size as the patchable constants to
; be copied (and at the same addresses, of course).  Additionally, space for
; the upload buffer, download buffer, command buffer, and housekeeping buffer
; is reserved.  This approach allows the linker to warn us if another XDATA
; allocation overlaps any of these areas.
;*****************************************************************************
   XSEG  at  RS01              ; reserve 1024 bytes for upload buffer
xRS01:   DS  1024

   XSEG  at  RS17              ; reserve 28 bytes for command packet
xRS17:   DS  28

   XSEG  at  TS01              ; reserve 1024 bytes for download buffer
xTS01:   DS  1024

   XSEG  at  TS17              ; reserve 1024 bytes for housekeeping buffer
xTS17:   DS  1024

   XSEG  at  PC04              ; reserve the patchable constants space
xPATCH:  DS  end_patchable_CSEG-patchable_CSEG
;-----------------------------------------------------------------------------

;*****************************************************************************
; Working copies of items which will go into the housekeeping packet are
; allocated here.  Subroutine 'BUILD_HKP' constructs the housekeeping
; packet from information herein and elsewhere.  Where possible, blocks of
; items here are layed out in the same order (within the block) as the
; expected order in housekeeping, in order to simplify and speed-up the
; copy-to-housekeeping which is performed in 'BUILD_HKP'.
;*****************************************************************************
   XSEG   at   PC00

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
; Memory Monitor parameters (KEEP IN THIS ORDER) ...
mLFDMEXTR:   DS    1        ; external/internal select bits
mLFDMDATA:   DS    1        ; data/code select bits
mLFDMONS:    DS    8        ; data values
mLFDMADD:    DS   16        ; addresses
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
; KEEP IN THIS ORDER ...
mLFDERR:     DS    8        ; 8 HST error locations
mLFDERRP:    DS   16        ; 8 HST error parameters
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
; KEEP IN THIS ORDER ...
mLFCPKTL:    DS    4        ; packet counter (long word)
mLFDLSTC:    DS    1        ; last DCE Op-code executed
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
; KEEP IN THIS ORDER ...
mTICKS:      DS    1        ; counts 20 msec intervals (1/50 second)
mLFCTIME:    DS    4        ; seconds counter
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

; Various others (need not be kept in order) ...

; Diagnostics and HST errors ...
tLFDDIAGS    equ   $        ; assembler need a little help with its math,
                            ; so create this 'equate' at the same address as
                            ; 'mLFDDIAGS'
mLFDDIAGS:   DS   64        ; Push-down stack of last 32 diagnostic msgs.
mDIAG_NUM:   DS    1        ; counter of total number of diagnostics

; Various counters ...
mLFDCMDR:    DS    2        ; commands received counter
mLFDCMDX:    DS    2        ; commands executed counter
mLFDPERF:    DS    2        ; DCE Performance monitor.  Exec. loop counter.
mLFMXFER:    DS    2        ; upload/download packet CRC
mCWNS:       DS    2        ; counts commands words received but not stored
mWNS:        DS    4        ; command long word received but not stored

; 6 status words (first 4 are 16-bits each, last 2 are 8-bits each) ...
mLFSBITS0:   DS    2
mLFSBITS1:   DS    2
mLFSBITS2:   DS    2
mLFSBITS3:   DS    2
mLFSBITS4:   DS    1
mLFSBITS5:   DS    1

             DS    PC04-$   ; Block out the rest of the space up to where
                            ; the patchable constants begin (address 'PC00').
;-----------------------------------------------------------------------------

END                         ; patchcst.a51

